Description Usage Arguments Details Value Author(s)
Desagregate a dateset for all the observations based on a specific variable with frequency greater to 1, taking in mind that the id variable needs to be unique.
1 | desagregate_df(df, ref_desgte, id)
|
df |
original dataset to desagregate |
ref_desgte |
reference desagregation variable |
id |
unique id variable |
This function has been design to check if the variable id is unique
filtered by the variable ref_desgte and if it is then for the
observations in ref_desgte with frequency greater than one desagregate
in each id, in other case return the observations in the same way for
each filter id.
the dataset df desagregated by the variable ref_desgte
Eduardo Trujillo
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.