Description Usage Arguments Details Value Note Author(s)
Create specific descriptive plots of the marginal distribution of a numeric variable on a specific levels of combination from factor variables.
1 | descr_stats_plots(num_int_var, marg_dist_df, marg_dist_choice = NULL)
|
num_int_var |
ONE NUMERICAL VARIABLE that represents the marginal distribution |
marg_dist_df |
numeric or integer vector that represent a marginal distribution |
marg_dist_choice |
Type of descriptive statistical analysis |
This function allows you to return different types of descriptive statistical plots from the marginal distribution of a numeric variable on a specific levels of combination from factor variables.
"This function returns different results based on the arguments marg_dist_choice argument".
If marg_dist_choice = "OGIVE", ogive plot of the marginal distribution marg_dist_df of num_int_var on a specific combination level.
If marg_dist_choice = "CUMMULATIVE", the accumulative distribution function plot of the marginal distribution marg_dist_df of num_int_var on a specific combination level.
If marg_dist_choice = "HISTOGRAM", the histogram plot of the marginal distribution marg_dist_df of num_int_var on a specific combination level.
If marg_dist_choice = "GENERAL_BOXPLOT", the box plot of the marginal distribution marg_dist_df of num_int_var on a specific combination level.
If marg_dist_choice = "BINS_BOXPLOT", box plot on each bin from the frequency table of the marginal distribution marg_dist_df of num_int_var on a specific combination level.
If marg_dist_choice = NULL, list where each sublist is one of the previous mentioned.
marg_dist_df needs to be a filter sublist from marg_dist function.
This function is applied to one numeric variable num_int_var
If you are not using a shiny app, is better to use general_descript_stats function.
Eduardo Trujillo
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.