Description Usage Arguments Details Value Author(s)
Split a dataset into unique and duplicate elements by an id reference
1 | dfsplit_test_equality(df, split_reference, test_reference, names)
|
df |
dataset to split |
split_reference |
variable of reference to split dataset |
test_reference |
variable of reference to test if elements of that variable are unique |
names |
names of the sublists unique and repeated. |
This function has been design for a given dataset split it by the variable
split_reference and divide it in sublists. This is if the variable
test_reference has unique elements or not.
List where each sublist is the unique and the duplicated
observations from df.
Eduardo Trujillo
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.